@@ -1,5 +1,5 @@
 """
-    authlib.oauth2.rfc6750.validator
+    fastapi_oauth.rfc6750.validator
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     Validate Bearer Token for in request, scope and token.
